@@ -11,6 +11,20 @@
 ##    
 ##########################################################################
 
+####################
+findInertInputs<-function(object,threshold=0.1){
+  P_hat=object@p*object@beta_hat*object@CL/sum(object@beta_hat*object@CL)
+  index_inert=which(P_hat<threshold)
+  
+  cat('The estimated normalized inverse range parameters are :', P_hat,'\n')
+  if(length(which(P_hat<0.1))>0){
+    cat('The inputs ', index_inert, 'are suspected to be inert inputs','\n')
+  }else{
+    cat('no input is suspected to be an inert input', '\n')
+  }
+  P_hat
+}
+
 ####################
 neg_log_marginal_post_approx_ref <- function(param,nugget, nugget.est,R0,X,output,CL,a,b,kernel_type,alpha) {
    #####this has mean X, we should also include the case where X is not zero
@@ -239,3 +253,53 @@ borehole <- function(xx)
   y <- frac1 / frac2
   return(y)
 }
+
+
+fried <- function(xx)
+{
+  ##########################################################################
+  #
+  # FRIEDMAN FUNCTION
+  #
+  # Authors: Sonja Surjanovic, Simon Fraser University
+  #          Derek Bingham, Simon Fraser University
+  # Questions/Comments: Please email Derek Bingham at dbingham@stat.sfu.ca.
+  #
+  # Copyright 2013. Derek Bingham, Simon Fraser University.
+  #
+  # THERE IS NO WARRANTY, EXPRESS OR IMPLIED. WE DO NOT ASSUME ANY LIABILITY
+  # FOR THE USE OF THIS SOFTWARE.  If software is modified to produce
+  # derivative works, such modified software should be clearly marked.
+  # Additionally, this program is free software; you can redistribute it 
+  # and/or modify it under the terms of the GNU General Public License as 
+  # published by the Free Software Foundation; version 2.0 of the License. 
+  # Accordingly, this program is distributed in the hope that it will be 
+  # useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
+  # of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
+  # General Public License for more details.
+  #
+  # For function details and reference information, see:
+  # http://www.sfu.ca/~ssurjano/
+  #
+  ##########################################################################
+  #
+  # INPUT:
+  #
+  # xx = c(x1, x2, x3, x4, x5)
+  #
+  ##########################################################################
+  
+  x1 <- xx[1]
+  x2 <- xx[2]
+  x3 <- xx[3]
+  x4 <- xx[4]
+  x5 <- xx[5]
+  
+  term1 <- 10 * sin(pi*x1*x2)
+  term2 <- 20 * (x3-0.5)^2
+  term3 <- 10*x4
+  term4 <- 5*x5
+  
+  y <- term1 + term2 + term3 + term4
+  return(y)
+}
